@@ -21,7 +21,6 @@ static char *get_string(PyObject *obj)
         PyObject *pyutf8 = PyUnicode_AsUTF8String(obj);
         if(pyutf8 == NULL)
             return NULL;
-        fprintf(stderr, "\n");
 #if PY_MAJOR_VERSION >= 3
         str = PyBytes_AsString(pyutf8);
 #else
@@ -143,6 +142,7 @@ static PyMethodDef methods[] = {
      "\n"
      "Runs the specified binary with the argument list argv under trace and "
      "writes\nthe captured events to SQLite3 database databasepath."},
+    { NULL, NULL, 0, NULL }
 };
 
 #if PY_MAJOR_VERSION >= 3
